==> dc-cudami-server-backend-jdbi-4.4.3-sources.jar: de/digitalcollections/cudami/server/backend/impl/jdbi/identifiable/agent/FamilyNameRepositoryImpl.java <==
package de.digitalcollections.cudami.server.backend.impl.jdbi.identifiable.agent;

import de.digitalcollections.cudami.server.backend.api.repository.identifiable.IdentifierRepository;
import de.digitalcollections.cudami.server.backend.api.repository.identifiable.agent.FamilyNameRepository;
import de.digitalcollections.cudami.server.backend.impl.jdbi.identifiable.IdentifiableRepositoryImpl;
import de.digitalcollections.model.api.identifiable.agent.FamilyName;
import de.digitalcollections.model.impl.identifiable.agent.FamilyNameImpl;
import org.jdbi.v3.core.Jdbi;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;

@Repository
public class FamilyNameRepositoryImpl extends IdentifiableRepositoryImpl<FamilyName>
    implements FamilyNameRepository {

  private static final Logger LOGGER = LoggerFactory.getLogger(FamilyNameRepositoryImpl.class);

  public static final String MAPPING_PREFIX = "fn";
  public static final String TABLE_ALIAS = "f";
  public static final String TABLE_NAME = "familynames";

  public static String getSqlInsertFields() {
    return IdentifiableRepositoryImpl.getSqlInsertFields();
  }

  /* Do not change order! Must match order in getSqlInsertFields!!! */
  public static String getSqlInsertValues() {
    return IdentifiableRepositoryImpl.getSqlInsertValues();
  }

  public static String getSqlSelectAllFields(String tableAlias, String mappingPrefix) {
    return getSqlSelectReducedFields(tableAlias, mappingPrefix);
  }

  public static String getSqlSelectReducedFields(String tableAlias, String mappingPrefix) {
    return IdentifiableRepositoryImpl.getSqlSelectReducedFields(tableAlias, mappingPrefix);
  }

  public static String getSqlUpdateFieldValues() {
    return IdentifiableRepositoryImpl.getSqlUpdateFieldValues();
  }

  @Autowired
  public FamilyNameRepositoryImpl(Jdbi dbi, IdentifierRepository identifierRepository) {
    super(
        dbi,
        identifierRepository,
        TABLE_NAME,
        TABLE_ALIAS,
        MAPPING_PREFIX,
        FamilyNameImpl.class,
        getSqlSelectAllFields(TABLE_ALIAS, MAPPING_PREFIX),
        getSqlSelectReducedFields(TABLE_ALIAS, MAPPING_PREFIX),
        getSqlInsertFields(),
        getSqlInsertValues(),
        getSqlUpdateFieldValues());
  }

  @Override
  public FamilyName save(FamilyName familyName) {
    super.save(familyName);
    FamilyName result = findOne(familyName.getUuid());
    return result;
  }

  @Override
  public FamilyName update(FamilyName familyName) {
    super.update(familyName);
    FamilyName result = findOne(familyName.getUuid());
    return result;
  }
}

==> dc-cudami-server-backend-jdbi-6.1.0-sources.jar: de/digitalcollections/cudami/server/backend/impl/jdbi/identifiable/agent/FamilyNameRepositoryImpl.java <==
package de.digitalcollections.cudami.server.backend.impl.jdbi.identifiable.agent;

import de.digitalcollections.cudami.model.config.CudamiConfig;
import de.digitalcollections.cudami.server.backend.api.repository.identifiable.agent.FamilyNameRepository;
import de.digitalcollections.cudami.server.backend.impl.jdbi.identifiable.IdentifiableRepositoryImpl;
import de.digitalcollections.model.identifiable.agent.FamilyName;
import org.jdbi.v3.core.Jdbi;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;

@Repository
public class FamilyNameRepositoryImpl extends IdentifiableRepositoryImpl<FamilyName>
    implements FamilyNameRepository {

  private static final Logger LOGGER = LoggerFactory.getLogger(FamilyNameRepositoryImpl.class);

  public static final String MAPPING_PREFIX = "fn";
  public static final String TABLE_ALIAS = "f";
  public static final String TABLE_NAME = "familynames";

  public static String getSqlInsertFields() {
    return IdentifiableRepositoryImpl.getSqlInsertFields();
  }

  /* Do not change order! Must match order in getSqlInsertFields!!! */
  public static String getSqlInsertValues() {
    return IdentifiableRepositoryImpl.getSqlInsertValues();
  }

  public static String getSqlSelectAllFields(String tableAlias, String mappingPrefix) {
    return getSqlSelectReducedFields(tableAlias, mappingPrefix);
  }

  public static String getSqlSelectReducedFields(String tableAlias, String mappingPrefix) {
    return IdentifiableRepositoryImpl.getSqlSelectReducedFields(tableAlias, mappingPrefix);
  }

  public static String getSqlUpdateFieldValues() {
    return IdentifiableRepositoryImpl.getSqlUpdateFieldValues();
  }

  @Autowired
  public FamilyNameRepositoryImpl(Jdbi dbi, CudamiConfig cudamiConfig) {
    super(
        dbi,
        TABLE_NAME,
        TABLE_ALIAS,
        MAPPING_PREFIX,
        FamilyName.class,
        getSqlSelectAllFields(TABLE_ALIAS, MAPPING_PREFIX),
        getSqlSelectReducedFields(TABLE_ALIAS, MAPPING_PREFIX),
        getSqlInsertFields(),
        getSqlInsertValues(),
        getSqlUpdateFieldValues(),
        cudamiConfig.getOffsetForAlternativePaging());
  }

  @Override
  public FamilyName save(FamilyName familyName) {
    super.save(familyName);
    FamilyName result = getByUuid(familyName.getUuid());
    return result;
  }

  @Override
  public FamilyName update(FamilyName familyName) {
    super.update(familyName);
    FamilyName result = getByUuid(familyName.getUuid());
    return result;
  }
}
